@@ -1,14 +1,8 @@
 import sys
 import os
-try:
-    import lib2to3
-except ImportError:
-    import pgen
-    import lib2to3
 
 path = [os.path.abspath('')]
 
-
 # default to None indicates 'relative paths' so that as a self-contained
 # archive, pyjs can run its tests.
 try:
@@ -29,5 +23,3 @@ MOD_SUFFIX = '.js'
 PYTHON = os.path.realpath(sys.executable) if sys.executable else None
 if PYTHON is None or not os.access(PYTHON, os.X_OK):
     PYTHON = 'python'
-
-
