@@ -556,7 +556,7 @@ function $pyjs_instance_method_get(inst, args,
     var kwargname = callee_args[1];
     var arg_names = callee_args['slice'](2);
 
-    console['debug'](inst['__name__'] + " " + args['callee']['__name__'] + " isinst " + inst['__is_instance__'] + " hva " + has_varargs + " hkwa " + has_kwargs + " va " + varargname + " kw " + kwargname + " al " + arg_names['length']);
+    //console['debug'](inst['__name__'] + " " + args['callee']['__name__'] + " isinst " + inst['__is_instance__'] + " hva " + has_varargs + " hkwa " + has_kwargs + " va " + varargname + " kw " + kwargname + " al " + arg_names['length']);
 
     var $l = {};
     var end;
@@ -636,7 +636,7 @@ function $pyjs_instance_method_get(inst, args,
         res = res + arg_name + " ";
     }
 
-    console['debug']("arg names " + res);
+    //console['debug']("arg names " + res);
 
     /* TODO: function arg checking */
     /*
@@ -659,7 +659,7 @@ if ($pyjs['options']['arg_instance_type']) {
     for (var k in $l) {
         res = res + k + " ";
     }
-    console['debug']("arg keys " + res);
+    //console['debug']("arg keys " + res);
     return $l;
 }
 
@@ -716,11 +716,11 @@ function $pyjs_default_args_handler($l, args, defaults_count,
         }
     }
     var default_pos = arg_names['length'] - defaults_count;
-    console['debug']("default_pos " + default_pos + " count " + defaults_count);
+    //console['debug']("default_pos " + default_pos + " count " + defaults_count);
     for (var i = 0; i < defaults_count; i++)
     {
         var default_name = arg_names[default_pos][0];
-        console['debug']("default_name " + default_name);
+        //console['debug']("default_name " + default_name);
         default_pos++;
         if (typeof $l[default_name] == 'undefined')
         {
